@@ -5,7 +5,7 @@ use warnings;
 use Carp;
 use List::Util qw( shuffle );
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 # fill the structure with the themes data
 our %META;
@@ -79,7 +79,7 @@ sub add_theme {
     }
 }
 
-sub themes { sort keys %META }
+sub themes { wantarray ? ( sort keys %META ) : scalar keys %META }
 
 # PRIVATE HELPER SUB
 sub _add_method {
@@ -218,6 +218,8 @@ See C<name()>. The default is the same as for the OO interface.
 
 =item metasimpsons
 
+=item metatld
+
 =item metatoto
 
 The convenience functions are exported as expected.
@@ -279,6 +281,10 @@ The whole shadok vocabulary. 4 words.
 
 The cast of the animated series.
 
+=item tld
+
+The list of top-level domainnames.
+
 =item toto
 
 The traditional French metasyntactic names.
@@ -728,3 +734,15 @@ bart lisa marge homer maggie moe mr_burns itchy scratchy grampa ned snowball
 # browser
 mozilla netscape msie mosaic links lynx w3m opera galeon konqueror safari
 camino dillo amaya arachne omniweb planetweb voyager
+# tld
+ad ae af ag ai al am an ao aq ar as at au aw ax az ba bb bd be bf bg bh
+bi bj bm bn bo br bs bt bv bw by bz ca cc cd cf cg ch ci ck cl cm cn co
+cr cs cu cv cx cy cz de dj dk dm do dz ec ee eg eh er es et fi fj fk fm
+fo fr fx ga gb gd ge gf gh gi gl gm gn gp gq gr gs gt gu gw gy hk hm hn
+hr ht hu id ie il in io iq ir is it jm jo jp ke kg kh ki km kn kp kr kw
+ky kz la lb lc li lk lr ls lt lu lv ly ma mc md mg mh mk ml mm mn mo mp
+mq mr ms mt mu mv mw mx my mz na nc ne nf ng ni nl no np nr nu nz om pa
+pe pf pg ph pk pl pm pn pr ps pt pw py qa re ro ru rw sa sb sc sd se sg sh
+si sj sk sl sm sn so sr st su sv sy sz tc td tf tg th tj tk tl tm tn to tp
+tr tt tv tw tz ua ug uk um us uy uz va vc ve vg vi vn vu wf ws ye yt yu za
+zm zr zw biz com edu gov int mil net org pro aero arpa coop info name nato
